// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package configuration

import (
	"github.com/stretchr/testify/assert"
	"reflect"
	"testing"
)

func TestResetErrors(t *testing.T) {

	defaults := ConfigStruct2{
		A: "Hello!",
	}

	c := New(defaults)

	assert.False(t, c.HasErrors())
	c.SetDefaultDirectories()
	assert.True(t, c.HasErrors())
	c.ResetErrors()
	assert.False(t, c.HasErrors())

	assert.Empty(t, c.Errors())
}

func TestNewFlagDoesNotExistError(t *testing.T) {
	err := newFlagDoesNotExistError("flag")
	_, ok := err.(FlagDoesNotExistError)
	assert.True(t, ok)
}

func TestNewPathAlreadyExistsError(t *testing.T) {
	err := newPathAlreadyExistsError("flag")
	_, ok := err.(PathAlreadyExistsError)
	assert.True(t, ok)
}

func TestNewPathDoesNotExistError(t *testing.T) {
	err := newPathDoesNotExistError("flag")
	_, ok := err.(PathDoesNotExistError)
	assert.True(t, ok)
}

func TestNewFormatNotSupportedError(t *testing.T) {
	err := newFormatNotSupportedError(Yaml)
	_, ok := err.(FormatNotSupportedError)
	assert.True(t, ok)
}

func TestNewUnsupportedTypeError(t *testing.T) {
	x := reflect.TypeOf("string")
	err := newUnsupportedTypeError(x)
	_, ok := err.(UnsupportedTypeError)
	assert.True(t, ok)
}

func TestNewUnsupportedReflectKindError(t *testing.T) {
	x := reflect.TypeOf("string")
	err := newUnsupportedReflectKindError(x)
	_, ok := err.(UnsupportedReflectKindError)
	assert.True(t, ok)
}

func TestNewFlagNotFoundError(t *testing.T) {
	err := newFlagNotFoundError("flag")
	_, ok := err.(FlagNotFoundError)
	assert.True(t, ok)
}

func TestNewMismatchedTypeError(t *testing.T) {
	x := reflect.TypeOf("string")
	err := newMismatchedTypeError(x, x)
	_, ok := err.(MismatchedTypeError)
	assert.True(t, ok)
}
